CKAN Budgets
============

A `CKAN <http://ckan.org/>`__ extension that improves handling of budget
data in CKAN. Central to the budget data handling are `budget data
packages <https://github.com/openspending/budget-data-package>`__.

When a CSV file is uploaded to CKAN and the CSV includes all of the
headers defined in the budget data package specification, the dataset is
automatically converted into a budget data package (i.e. it can be
exported as a budget data package). So automatically the budget data
distribution is standardised and becomes usable in the different tools
that support budget data packages.

Installation
------------

Simply clone this library and run

::

    python setup.py install

Then add ``budgets`` to the list in ``ckan.plugins`` in your CKAN
configuration file. Restart your webserver and budget data is
automatically handled for you.

License
-------

Copyright (C) 2014 Open Knowledge Foundation

This program is free software: you can redistribute it and/or modify it
under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero
General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program. If not, see http://www.gnu.org/licenses/.
